@@ -1042,9 +1042,10 @@ def raw_vt_integral_fho(T: float, deg: int, sigma: float, mass: float, beta: flo
         else:
             mult = prob.fact_div_fact(i + delta, i) / (factorial(-delta) ** 2)
 
+        svt = prob.svt(delta)
         if model == 'VSS':
             f = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
-                                                  i, delta, molecule_depth)\
+                                                  i, delta, molecule_depth, svt)\
                         * elastic_omega_g_only_vss(g, deg, vsso)
             if not nokt:
                 return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * vssc\
@@ -1056,7 +1057,7 @@ def raw_vt_integral_fho(T: float, deg: int, sigma: float, mass: float, beta: flo
                             * integrate.quad(f, 0, np.inf)[0]
         else:
             f = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
-                                                  i, delta, molecule_depth)\
+                                                  i, delta, molecule_depth, svt)\
                         * elastic_omega_g_only_rigid_sphere(g, deg)
             if not nokt:
                 return mult * (sigma ** 2) * ((T * constants.pi * constants.k / (2.0 * mass)) ** 0.5)\
@@ -1134,9 +1135,11 @@ def raw_vv_integral_fho(T: float, deg: int, sigma: float, mass: float, beta: flo
             mult = prob.fact_div_fact(i, i + i_delta) * prob.fact_div_fact(k - i_delta, k) / (factorial(i_delta) ** 2)
         else:
             mult = prob.fact_div_fact(i + i_delta, i) * prob.fact_div_fact(k, k - i_delta) / (factorial(-i_delta) ** 2)
+
+        svv = prob.svv(i_delta)
         if model == 'VSS':
             f = lambda g: prob.vv_prob_g_only_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2, ve_after2,
-                                                  i, k, i_delta) * elastic_omega_g_only_vss(g, deg, vsso)
+                                                  i, k, i_delta, svv) * elastic_omega_g_only_vss(g, deg, vsso)
             if not nokt:
                 return mult * (constants.physical_constants['Angstrom star'][0] ** 2) * vssc\
                             * ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5) * (T ** (-vsso))\
@@ -1147,7 +1150,8 @@ def raw_vv_integral_fho(T: float, deg: int, sigma: float, mass: float, beta: flo
                             * integrate.quad(f, 0, np.inf)[0]
         else:
             f = lambda g: prob.vv_prob_g_only_fho(g, T, mass, beta, ve_before1, ve_after1, ve_before2,
-                                                  ve_after2, i, k, i_delta) * elastic_omega_g_only_rigid_sphere(g, deg)
+                                                  ve_after2, i, k, i_delta, svv)\
+                          * elastic_omega_g_only_rigid_sphere(g, deg)
             if not nokt:
                 return mult * (sigma ** 2) * ((T * constants.pi * constants.k / (2.0 * mass)) ** 0.5)\
                             * integrate.quad(f, 0, np.inf)[0]
