@@ -40,6 +40,46 @@ def fact_div_fact(start: int, end: int) -> float:
         return np.prod(np.arange(start + 1.0, end + 1.0, 1.0))
 
 
+def svt(delta: int) -> float:
+    """
+    Helper function, calculates the steric factor for VT transitions
+
+    Parameters
+    ----------
+    delta : int
+        the change in vibrational level
+
+    Returns
+    -------
+    float
+        The steric factor
+    """
+    s = delta
+    if delta < 0:
+        s *= -1.0
+    return 1. / (constants.pi * s)
+
+
+def svv(delta: int) -> float:
+    """
+    Helper function, calculates the steric factor for VV transitions
+
+    Parameters
+    ----------
+    delta : int
+        the change in vibrational level
+
+    Returns
+    -------
+    float
+        The steric factor
+    """
+    s = delta
+    if delta < 0:
+        s *= -1.0
+    return ((factorial(s + 3)) * ((1. + 1. / (2. ** (s - 1))) ** 4)) / ((2. ** (s + 8)) * (s + 1) * (s + 1) * 6)
+
+
 def vel_avg_vt(g: float, ve_before: float, ve_after: float, m: float) -> float:
     """Returns the arithmetic mean of the relative velocity of particles before and after
     a VT transition (using the energy conservation law) **M(i1) + P -> M(i2) + P**
@@ -141,7 +181,6 @@ def vt_probability_fho(g: float, T: float, mass: float, beta: float, ve_before:
     float
         VT transition probability
     """
-    svt = 0.5
 
     if delta > 0:
         s = delta * 1.0
@@ -161,12 +200,12 @@ def vt_probability_fho(g: float, T: float, mass: float, beta: float, ve_before:
 
     eps = (cosh((1.0 + phi) * omega / (beta * vel))
            / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
-    eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
+    eps *= 4.0 * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h * constants.pi * s)
     return ns * (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
 
 
 def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int,
-                       delta: int, depth: float) -> float:
+                       delta: int, depth: float, svt: float=0.33) -> float:
     """Returns the velocity-dependent part of the probability of a VT transition using
     the FHO (Forced harmonic oscillator) model **M(i) + P -> M(i + delta) + P**
 
@@ -190,13 +229,14 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
         the change in vibrational level of the molecule
     depth : float
         the potential well depth of the molecule
+    svt : float
+        the steric factor
 
     Returns
     -------
     float
         Velocity-dependent part of the VT transition probability
     """
-    svt = 0.5
 
     vel = vel_avg_vt(g * (2 * constants.k * T / mass) ** 0.5, ve_before, ve_after, mass)
     if vel < 0.0:
@@ -220,8 +260,9 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
         return eps * exp(-i * eps)
     elif delta > 0:
         s = delta * 1.0
-        omega = (ve_after - ve_before) / (delta * constants.hbar)
+        omega = (ve_after - ve_before) / (s * constants.hbar)
         ns = fact_div_fact(i, i + delta)
+
         phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
         eps = (cosh((1.0 + phi) * omega / (beta * vel))
                / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
@@ -229,8 +270,9 @@ def vt_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before:
         return (eps ** s) * exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1))
     else:
         s = -delta * 1.0
-        omega = (ve_before - ve_after) / (delta * constants.hbar)
+        omega = (ve_before - ve_after) / (s * constants.hbar)
         ns = fact_div_fact(i + delta, i)
+
         phi = 2.0 * atan(((2.0 * depth / mass) ** 0.5) / vel)
         eps = (cosh((1.0 + phi) * omega / (beta * vel))
                / (sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
@@ -273,7 +315,6 @@ def vv_probability_fho(g: float, T: float, mass: float, beta: float, ve_before1:
     float
         VV transition probability
     """
-    svv = 0.04
 
     if i_delta > 0:
         s = i_delta * 1.0
@@ -284,6 +325,8 @@ def vv_probability_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         ns1 = fact_div_fact(i + i_delta, i)
         ns2 = fact_div_fact(k, k - i_delta)
 
+    svv = ((factorial(s + 3)) * ((1. + 1. / (2. ** (s - 1))) ** 4)) / ((2. ** (s + 8)) * (s + 1) * (s + 1) * 6)
+
     vel = vel_avg_vv(g * (2.0 * constants.k * T / mass) ** 0.5, ve_before1, ve_after1, ve_before2, ve_after2, mass)
 
     if vel < 0:
@@ -301,11 +344,11 @@ def vv_probability_fho(g: float, T: float, mass: float, beta: float, ve_before1:
     else:
         rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-    return rhoxi * ns1 * ns2 * exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
+    return (rhoxi ** s) * ns1 * ns2 * exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
 
 
 def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1: float, ve_after1: float,
-                       ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int) -> float:
+                       ve_before2: float, ve_after2: float, i: int, k: int, i_delta: int, svv: float=0.04) -> float:
     """Returns the velocity-dependent part of the probability of a VV transition using the FHO
     (Forced harmonic oscillator) model **M1(i) + M2(k) -> M1(i + i_delta) + M2(k - i_delta)**
 
@@ -333,13 +376,14 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         the vibrational level of molecule M2
     i_delta : int
         the change in vibrational level of the molecule M1
+    svv : float
+        the steric factor
 
     Returns
     -------
     float
         Velocity-dependent part of the VV transition probability
     """
-    svv = 0.04
     vel = vel_avg_vv(g * (2.0 * constants.k * T / mass) ** 0.5, ve_before1, ve_after1, ve_before2, ve_after2, mass)
     if vel < 0:
         return 0.0
@@ -347,9 +391,10 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
     if i_delta == 1:
         omega1 = (ve_after1 - ve_before1) / constants.hbar
         omega2 = (ve_before2 - ve_after2) / constants.hbar
+
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)  # 0.0078125 is 0.03125 * 0.25, svv=0.03125
         else:
             rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
@@ -360,15 +405,15 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
-            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
+            rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)  # 0.0078125 is 0.03125 * 0.25, svv=0.03125
         else:
             rhoxi = svv * ((omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
         return rhoxi * exp(-(i * (k + 1)) * rhoxi)
     elif i_delta > 0:
         s = i_delta * 1.0
-        omega1 = (ve_after1 - ve_before1) / constants.hbar
-        omega2 = (ve_before2 - ve_after2) / constants.hbar
+        omega1 = (ve_after1 - ve_before1) / (s * constants.hbar)
+        omega2 = (ve_before2 - ve_after2) / (s * constants.hbar)
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
@@ -376,12 +421,12 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         else:
             rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-        return rhoxi * exp(-2.0 * ((fact_div_fact(i, i + i_delta) * fact_div_fact(k - i_delta, k)) ** (1.0 / s))
-                     * rhoxi / (s + 1))
+        return (rhoxi ** s) * exp(-2.0 * ((fact_div_fact(i, i + i_delta) * fact_div_fact(k - i_delta, k)) ** (1.0 / s))
+                            * rhoxi / (s + 1))
     else:
         s = -i_delta * 1.0
-        omega1 = (ve_before1 - ve_after1) / constants.hbar
-        omega2 = (ve_after2 - ve_before2) / constants.hbar
+        omega1 = (ve_before1 - ve_after1) / (s * constants.hbar)
+        omega2 = (ve_after2 - ve_before2) / (s * constants.hbar)
         xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
@@ -389,5 +434,5 @@ def vv_prob_g_only_fho(g: float, T: float, mass: float, beta: float, ve_before1:
         else:
             rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (sinh(xi) ** 2))
 
-        return rhoxi * exp(-2.0 * ((fact_div_fact(i + i_delta, i) * fact_div_fact(k, k - i_delta)) ** (1.0 / s))
-                     * rhoxi / (s + 1))
\ No newline at end of file
+        return (rhoxi ** s) * exp(-2.0 * ((fact_div_fact(i + i_delta, i) * fact_div_fact(k, k - i_delta)) ** (1.0 / s))
+                            * rhoxi / (s + 1))
\ No newline at end of file
