@@ -8,7 +8,7 @@ __status__ = "Production"
 
 import numpy as np
 from scipy import constants
-from .crosssection import raw_diss_integral_rigid_sphere
+from .crosssection import raw_diss_integral
 from .particles import Molecule, MoleculeMultiT, Atom, MoleculeQuasi
 from math import exp
 
@@ -70,9 +70,9 @@ def diss_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mo
 
 
 def diss_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, i: int,
-                           center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+                           center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
     """Calculates the state-to-state non-equilibrium dissociation rate constant using the generalized
-    omega integral over the rigid-sphere crosssection
+    omega integral over the VSS or rigid sphere crosssection
 
     Parameters
     ----------
@@ -92,18 +92,30 @@ def diss_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, i: i
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the
         dissociating molecule,
         if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+        
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
     float
         Non-equilibrium dissociation state-to-state rate constant
     """
-    if isinstance(molecule, MoleculeMultiT):
-        return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i] + molecule.vibr_zero,
-                                              molecule.diss, center_of_mass, vl_dependent)
+    if model == 'VSS':
+        pass
     else:
-        return raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i],
-                                              molecule.diss, center_of_mass, vl_dependent)
+        if isinstance(molecule, MoleculeMultiT):
+            return raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                              molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
+                                              center_of_mass, vl_dependent, model)
+        else:
+            return raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                              molecule.vibr[i], molecule.diss,
+                                              center_of_mass, vl_dependent, model)
 
 
 def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom,
@@ -151,9 +163,9 @@ def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Mol
 
 
 def rec_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom, i: int,
-                              center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+                          center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
     """Calculates the state-to-state recombination rate constant using the generalized
-    omega integral over the rigid-sphere crosssection
+    omega integral over the VSS or rigid sphere crosssection
 
     Parameters
     ----------
@@ -177,20 +189,32 @@ def rec_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the
         dissociating molecule,
         if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+        
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
     float
         Recombination state-to-state rate constant
     """
-    if isinstance(molecule, MoleculeMultiT):
-        return raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                             atom2.mass, molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
-                                             center_of_mass, vl_dependent)
+    if model == 'VSS':
+        pass
     else:
-        return raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
+        if isinstance(molecule, MoleculeMultiT):
+            return raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                             molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                             atom2.mass, molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
+                                             center_of_mass, vl_dependent, model)
+        else:
+            return raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                             molecule.Z_rot(T), molecule.mass, atom1.mass,
                                              atom2.mass, molecule.vibr[i], molecule.diss,
-                                             center_of_mass, vl_dependent)
+                                             center_of_mass, vl_dependent, model)
 
 
 def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
@@ -240,9 +264,9 @@ def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molec
 
 
 def diss_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi,
-                       center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+                       center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
     """Calculates the multi(one)-temperature non-equilibrium dissociation rate constant using the generalized
-    omega integral over the rigid-sphere crosssection
+    omega integral over the VSS or rigid sphere crosssection
 
     Parameters
     ----------
@@ -262,25 +286,37 @@ def diss_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecul
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the
         dissociating molecule,
         if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+        
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
 
+        defaults to 'VSS'
+        
     Returns
     -------
     float
         Non-equilibrium dissociation rate constant
     """
     res = 0.0
-    if isinstance(molecule, MoleculeMultiT):
-        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-            res += molecule.vibr_exp(T, T1, i) \
-                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i] + molecule.vibr_zero,
-                                                    molecule.diss, center_of_mass, vl_dependent)
-        return res / molecule.Z_vibr(T, T1)
+    if model == 'VSS':
+        pass
     else:
-        for i in range(molecule.num_vibr + 1):
-            res += molecule.vibr_exp(T, i) \
-                   * raw_diss_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.vibr[i], molecule.diss,
-                                                    center_of_mass, vl_dependent)
-        return res / molecule.Z_vibr(T)
+        if isinstance(molecule, MoleculeMultiT):
+            for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+                res += molecule.vibr_exp(T, T1, i) \
+                       * raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                                    molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
+                                                    center_of_mass, vl_dependent, model)
+            return res / molecule.Z_vibr(T, T1)
+        else:
+            for i in range(molecule.num_vibr + 1):
+                res += molecule.vibr_exp(T, i) \
+                       * raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                                    molecule.vibr[i], molecule.diss,
+                                                    center_of_mass, vl_dependent, model)
+            return res / molecule.Z_vibr(T)
 
 
 def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
@@ -336,9 +372,9 @@ def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecu
 
 
 def rec_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: MoleculeQuasi, atom1: Atom, atom2: Atom,
-                      center_of_mass: bool=True, vl_dependent: bool=True) -> float:
+                      center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
     """Calculates the averaged recombination rate constant using the generalized
-    omega integral over the rigid-sphere crosssection
+    omega integral over the VSS or rigid sphere crosssection
 
     Parameters
     ----------
@@ -362,6 +398,13 @@ def rec_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecule
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the
         dissociating molecule,
         if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+        
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
@@ -369,17 +412,22 @@ def rec_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecule
         Averaged recombination rate constant
     """
     res = 0.0
-    if isinstance(molecule, MoleculeMultiT):
-        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-            res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                                 atom2.mass, molecule.vibr[i] + molecule.vibr_zero,
-                                                 molecule.diss, center_of_mass, vl_dependent)
+    if model == 'VSS':
+        pass
     else:
-        for i in range(molecule.num_vibr + 1):
-            res += raw_rec_rate_rigid_sphere_sts(T, idata[1], idata[0], molecule.Z_rot(T), molecule.mass, atom1.mass,
+        if isinstance(molecule, MoleculeMultiT):
+            for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+                res += raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                                 molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                                 atom2.mass, molecule.vibr[i] + molecule.vibr_zero,
+                                                 molecule.diss, center_of_mass, vl_dependent, model)
+        else:
+            for i in range(molecule.num_vibr + 1):
+                res += raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
+                                                 molecule.Z_rot(T), molecule.mass, atom1.mass,
                                                  atom2.mass, molecule.vibr[i], molecule.diss,
-                                                 center_of_mass, vl_dependent)
-    return res
+                                                 center_of_mass, vl_dependent, model)
+        return res
 
 
 def raw_k_diss_eq(T: float, arrhenius_n: float, arrhenius_A: float, molecule_diss: float) -> float:
@@ -432,10 +480,11 @@ def raw_diss_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
     return Z_diss * raw_k_diss_eq(T, arrhenius_n, arrhenius_A, molecule_diss)
 
 
-def raw_diss_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, molecule_vibr: float, molecule_diss: float,
-                                   center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the state-to-state non-equilibrium dissociation rate constant using the rigid-sphere
-    crosssection, *raw* version
+def raw_diss_rate_integral_sts(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                               molecule_vibr: float, molecule_diss: float,
+                               center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
+    """Calculates the state-to-state non-equilibrium dissociation rate constant using the generalized
+    omega integral over the VSS or rigid sphere crosssection, *raw* version
 
     Parameters
     ----------
@@ -445,6 +494,10 @@ def raw_diss_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, molecule
         the collision diameter :math:`\\sigma_{cd}`
     mass : float
         the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     molecule_vibr : float
         the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
         is ``False``, can be any value) (with no offset)
@@ -457,14 +510,21 @@ def raw_diss_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, molecule
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the
         dissociating molecule,
         if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
     float
         Non-equilibrium dissociation rate constant
     """
-    return 8.0 * raw_diss_integral_rigid_sphere(T, 0, sigma, mass, molecule_vibr, molecule_diss, center_of_mass,
-                                                vl_dependent, False)
+    return 8.0 * raw_diss_integral(T, 0, sigma, mass, vssc, vsso, molecule_vibr, molecule_diss, center_of_mass,
+                                   vl_dependent, model, False)
 
 
 def raw_rec_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A: float,
@@ -508,11 +568,12 @@ def raw_rec_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
            * raw_diss_rate_treanor_marrone_sts(T, arrhenius_n, arrhenius_A, Z_diss, molecule_diss)
 
 
-def raw_rec_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, Z_rot: float, mass_molecule: float,
-                                  mass_atom1: float, mass_atom2: float, molecule_vibr: float, molecule_diss: float,
-                                  center_of_mass: bool=True, vl_dependent: bool=True) -> float:
-    """Calculates the state-to-state recombination rate constant using the rigid-sphere
-    crosssection, *raw* version
+def raw_rec_rate_integral_sts(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+                              Z_rot: float, mass_molecule: float, mass_atom1: float, mass_atom2: float,
+                              molecule_vibr: float, molecule_diss: float,
+                              center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
+    """Calculates the state-to-state recombination rate constant using the generalized
+    omega integral over the VSS or rigid sphere crosssection, *raw* version
 
     Parameters
     ----------
@@ -522,6 +583,10 @@ def raw_rec_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, Z_rot: fl
         the collision diameter :math:`\\sigma_{cd}`
     mass : float
         the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot : float
         the value of the rotational partition function of the molecule which dissociates
     mass_molecule : float
@@ -542,6 +607,13 @@ def raw_rec_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, Z_rot: fl
         if ``True``, the dissociation crosssection takes into account the vibrational energy of the
         dissociating molecule,
         if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
@@ -551,4 +623,5 @@ def raw_rec_rate_rigid_sphere_sts(T: float, sigma: float, mass: float, Z_rot: fl
     return Z_rot * (constants.h ** 3) * ((mass_molecule / (2.0 * mass_atom1
                                                            * mass_atom2 * constants.pi * constants.k * T)) ** 1.5)\
            * exp(-(molecule_diss - molecule_vibr) / (constants.k * T))\
-           * raw_diss_rate_rigid_sphere_sts(T, sigma, mass, molecule_vibr, molecule_diss, center_of_mass, vl_dependent)
\ No newline at end of file
+           * raw_diss_rate_integral_sts(T, sigma, mass, vssc, vsso, molecule_vibr, molecule_diss,
+                                        center_of_mass, vl_dependent, model)
