@@ -93,7 +93,7 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: Molecule, n: float, infc
 
 
 def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: Particle, n: float,
-                     rig_sphere: bool=False) -> float:
+                     model: str='VSS') -> float:
     """Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference)
 
@@ -112,6 +112,13 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: P
     rig_sphere : bool, optional
         if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
         defaults to ``False``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
@@ -123,11 +130,11 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: Molecule, partner: P
                                                      molecule.Z_rot(T), partner.Z_rot(T),
                                                      molecule.rot_symmetry, partner.rot_symmetry, molecule.rot_const,
                                                      partner.rot_const, molecule.num_rot, partner.num_rot,
-                                                     molecule.name == partner.name, n, rig_sphere)
+                                                     molecule.name == partner.name, n, model)
     else:
         return raw_rot_rel_time_def_atom_partner(T, idata[1], idata[0], idata[9], idata[10],
                                                  molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const,
-                                                 molecule.num_rot, n, rig_sphere)
+                                                 molecule.num_rot, n, model)
 
 
 def Zr(T: float, idata: np.ndarray, molecule: Molecule, infcoll: float, model: str='VSS') -> float:
@@ -253,7 +260,7 @@ def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
                                           molecule_rot_symmetry1: float, molecule_rot_symmetry2: float,
                                           molecule_rot_const1: float, molecule_rot_const2: float,
                                           molecule_num_rot1: int, molecule_num_rot2: int, same_partner: bool,
-                                          n: float, rig_sphere: bool=False) -> float:
+                                          n: float, model: str='VSS') -> float:
     """Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference) for the case when the partner is a molecule, *raw* version
 
@@ -292,9 +299,13 @@ def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
         set to ``False``
     n : float
         the numeric density of the mixture
-    rig_sphere : bool, optional
-        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
-        defaults to ``False``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
@@ -303,27 +314,27 @@ def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
     """
 
     if same_partner:
-        return 0.5 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
+        return 0.5 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, model, False)
                       * (2 * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1,
-                                              molecule_rot_const1, molecule_num_rot1, False, False, False)
+                                              molecule_rot_const1, molecule_num_rot1, False, model, False)
                          + 2 * cs.raw_dE_rot_c_dE_rot_d(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2,
                                                         molecule_rot_symmetry1, molecule_rot_symmetry2,
                                                         molecule_rot_const1, molecule_rot_const2,
-                                                        molecule_num_rot1, molecule_num_rot2, False, False, False)))
+                                                        molecule_num_rot1, molecule_num_rot2, False, model, False)))
     else:
-        return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
-                       * cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2, molecule_rot_symmetry1,
-                                                   molecule_rot_symmetry2, molecule_rot_const1, molecule_rot_const2,
-                                                   molecule_num_rot1, molecule_num_rot2, False, False, False)
+        return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, model, False)
+                       * (cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2, molecule_rot_symmetry1,
+                                                    molecule_rot_symmetry2, molecule_rot_const1, molecule_rot_const2,
+                                                    molecule_num_rot1, molecule_num_rot2, False, model, False)
                        + cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot2, Z_rot1, molecule_rot_symmetry2,
                                                    molecule_rot_symmetry1, molecule_rot_const2, molecule_rot_const1,
-                                                   molecule_num_rot2, molecule_num_rot1, False, False, False))
+                                                   molecule_num_rot2, molecule_num_rot1, False, model, False)))
         
         
 def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
                                       Z_rot: float, molecule_rot_symmetry: float,
                                       molecule_rot_const: float, molecule_num_rot: int, n: float,
-                                      rig_sphere: bool=False) -> float:
+                                      model: str='VSS') -> float:
     """Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference) for the case when the partner is an atom, *raw* version
 
@@ -350,18 +361,22 @@ def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc:
         the amount of rotational levels in the molecule
     n : float
         the numeric density of the mixture
-    rig_sphere : bool, optional
-        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
-        defaults to ``False``
+    model : str, optional
+        the elastic crosssection model to be used, possible values:
+
+            * 'RS' (Rigid Sphere model)
+            * 'VSS' (Variable Soft Sphere model)
+
+        defaults to 'VSS'
 
     Returns
     -------
     float
         Rotational relaxation time
     """
-    return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
+    return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, model, False)
                    * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot, molecule_rot_symmetry,
-                                      molecule_rot_const, molecule_num_rot, False, False, False))
+                                      molecule_rot_const, molecule_num_rot, False, model, False))
 
 
 def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflection: float, vsso_deflection: float,
